@@ -1,5 +1,3 @@
-/* $Id: msg_limits.h,v 1.25 2005/06/07 09:54:43 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -43,14 +41,14 @@ typedef struct _glibtop_msg_limits	glibtop_msg_limits;
 
 struct _glibtop_msg_limits
 {
-	guint64	flags,
-		msgpool,	/* GLIBTOP_IPC_MSGPOOL	*/
-		msgmap,		/* GLIBTOP_IPC_MSGMAP	*/
-		msgmax,		/* GLIBTOP_IPC_MSGMAX	*/
-		msgmnb,		/* GLIBTOP_IPC_MSGMNB	*/
-		msgmni,		/* GLIBTOP_IPC_MSGMNI	*/
-		msgssz,		/* GLIBTOP_IPC_MSGSSZ	*/
-		msgtql;		/* GLIBTOP_IPC_MSGTQL	*/
+	guint64	flags;
+	guint64 msgpool;	/* GLIBTOP_IPC_MSGPOOL	*/
+	guint64 msgmap;		/* GLIBTOP_IPC_MSGMAP	*/
+	guint64 msgmax;		/* GLIBTOP_IPC_MSGMAX	*/
+	guint64 msgmnb;		/* GLIBTOP_IPC_MSGMNB	*/
+	guint64 msgmni;		/* GLIBTOP_IPC_MSGMNI	*/
+	guint64 msgssz;		/* GLIBTOP_IPC_MSGSSZ	*/
+	guint64 msgtql;		/* GLIBTOP_IPC_MSGTQL	*/
 };
 
 void glibtop_get_msg_limits(glibtop_msg_limits *buf);
@@ -64,10 +62,10 @@ void glibtop_get_msg_limits(glibtop_msg_limits *buf);
 void glibtop_get_msg_limits_l (glibtop *server, glibtop_msg_limits *buf);
 
 #if GLIBTOP_SUID_MSG_LIMITS
-void glibtop_init_msg_limits_p (glibtop *server);
+void _glibtop_init_msg_limits_p (glibtop *server);
 void glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf);
 #else
-void glibtop_init_msg_limits_s (glibtop *server);
+void _glibtop_init_msg_limits_s (glibtop *server);
 void glibtop_get_msg_limits_s (glibtop *server, glibtop_msg_limits *buf);
 #endif
 
