@@ -34,7 +34,7 @@ static const unsigned long _glibtop_sysdeps_mem =
 /* Init function. */
 
 void
-glibtop_init_mem_s (glibtop *server)
+_glibtop_init_mem_s (glibtop *server)
 {
 	server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
@@ -48,11 +48,9 @@ glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
 	char buffer [BUFSIZ];
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
-
 	memset(buf, 0, sizeof *buf);
 
-	file_to_buffer(server, buffer, FILENAME);
+	file_to_buffer(server, buffer, sizeof buffer, FILENAME);
 
 	buf->total  = get_scaled(buffer, "MemTotal:");
 	buf->free   = get_scaled(buffer, "MemFree:");
